@@ -12,7 +12,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from typing import TYPE_CHECKING, Any
+from typing import Any
 
 from rich.console import Console, RenderableType
 from rich.panel import Panel
