@@ -15,12 +15,22 @@
 API_KEY_HEADER_NAME = "X-Argilla-Api-Key"
 WORKSPACE_HEADER_NAME = "X-Argilla-Workspace"
 
+DATABASE_SQLITE = "sqlite"
+DATABASE_POSTGRESQL = "postgresql"
+
+SEARCH_ENGINE_ELASTICSEARCH = "elasticsearch"
+SEARCH_ENGINE_OPENSEARCH = "opensearch"
+
 DEFAULT_USERNAME = "argilla"
 DEFAULT_PASSWORD = "1234"
 DEFAULT_API_KEY = "argilla.apikey"
 
+DEFAULT_DATABASE_SQLITE_TIMEOUT = 5
+
+DEFAULT_DATABASE_POSTGRESQL_POOL_SIZE = 15
+DEFAULT_DATABASE_POSTGRESQL_MAX_OVERFLOW = 10
+
 DEFAULT_MAX_KEYWORD_LENGTH = 128
-DEFAULT_TELEMETRY_KEY = "C6FkcaoCbt78rACAgvyBxGBcMB3dM3nn"
 
 # Questions settings defaults
 DEFAULT_LABEL_SELECTION_OPTIONS_MAX_ITEMS = 500
@@ -29,6 +39,4 @@ DEFAULT_SPAN_OPTIONS_MAX_ITEMS = 500
 # The metadata field name prefix defined for protected (non-searchable) values
 PROTECTED_METADATA_FIELD_PREFIX = "_"
 
-ES_INDEX_REGEX_PATTERN = r"^(?!-|_)[a-z0-9-_]+$"
-
 JS_MAX_SAFE_INTEGER = 9007199254740991
