@@ -12,13 +12,12 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from typing import Any, Dict, Union
+from typing import Union
 
-from argilla_server.schemas.v1.settings import ArgillaSettings, HuggingfaceSettings, Settings
+from argilla_server.api.schemas.v1.settings import ArgillaSettings, Settings, HuggingfaceSettings
+from argilla_server.integrations.huggingface.spaces import HUGGINGFACE_SETTINGS
 from argilla_server.settings import settings
 
-HUGGINGFACE_SETTINGS = HuggingfaceSettings()
-
 
 def get_settings() -> Settings:
     return Settings(
@@ -28,7 +27,7 @@ def get_settings() -> Settings:
 
 
 def _get_argilla_settings() -> ArgillaSettings:
-    argilla_settings = ArgillaSettings()
+    argilla_settings = ArgillaSettings(share_your_progress_enabled=settings.enable_share_your_progress)
 
     if _get_huggingface_settings():
         argilla_settings.show_huggingface_space_persistent_storage_warning = (
@@ -40,4 +39,4 @@ def _get_argilla_settings() -> ArgillaSettings:
 
 def _get_huggingface_settings() -> Union[HuggingfaceSettings, None]:
     if HUGGINGFACE_SETTINGS.is_running_on_huggingface:
-        return HUGGINGFACE_SETTINGS
+        return HuggingfaceSettings.model_validate(HUGGINGFACE_SETTINGS)
