@@ -12,5 +12,4 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from .base_errors import *
-from .error_handler import *
+from .base_errors import *  # noqa
