@@ -15,6 +15,6 @@
 # This line is included here since some enums are already imported from `argilla_server.models`.
 # We need to review and avoid this. This is only a workaround to not change everything right now
 
-from argilla_server.enums import *  # noqa: I001
-from .database import *  # noqa: I001
-from .metadata_properties import *  # noqa: I001
+from argilla_server.enums import *  # noqa
+from .database import *  # noqa
+from .metadata_properties import *  # noqa
