@@ -16,8 +16,11 @@ from typing import Any, Optional
 
 from starlette.authentication import BaseUser
 
+from argilla_server.enums import UserRole
 from argilla_server.security.authentication.claims import Claims
 
+_DEFAULT_USER_ROLE = UserRole.annotator
+
 
 class UserInfo(BaseUser, dict):
     """User info from a provider."""
@@ -26,6 +29,19 @@ class UserInfo(BaseUser, dict):
     def is_authenticated(self) -> bool:
         return True
 
+    @property
+    def username(self) -> str:
+        return self["username"]
+
+    @property
+    def first_name(self) -> str:
+        return self.get("first_name") or self.username
+
+    @property
+    def role(self) -> UserRole:
+        role = self.get("role") or _DEFAULT_USER_ROLE
+        return UserRole(role)
+
     def use_claims(self, claims: Optional[Claims]) -> "UserInfo":
         claims = claims or {}
 
