@@ -13,5 +13,3 @@
 #  limitations under the License.
 
 from .params import parse_query_param, parse_uuids
-from .span_utils import SpanUtils
-from .utils import limit_value_length
