@@ -18,9 +18,6 @@
 # For more info, please visit https://gist.github.com/EricCousineau-TRI/8a2d1550f5fa4be4fed87d55a522dbf2
 import os
 
-from argilla_server.daos.backend.client_adapters.factory import ClientAdapterFactory
-from argilla_server.settings import settings
-
 os.environ.update(
     OMP_NUM_THREADS="1",
     OPENBLAS_NUM_THREADS="1",
